#include "stdafx.h"
#include "DDSParamDialog.h"
#include "UserInputRange.h"

//--------------------------------------------------------------------------------
DDSParamDialog::DDSParamDialog(wxWindow *parent, OscilloscopeHard &hard)
  : DDSParamDialogDesign(parent),
    m_hard(hard)
{
  m_staticTextFreq->SetLabel(
    wxString::Format(_("Frequency (%.1f - %.1f) [Hz]:"), USER_MIN_DDS_FREQ, USER_MAX_DDS_FREQ));
  m_staticTextAmp->SetLabel(
    wxString::Format(_("Amplitude (0 - %d) [mV]:"), USER_MAX_DDS_AMP));
  m_staticTextOffset->SetLabel(
    wxString::Format(_("Offset (%d - %d) [mV]:"), -USER_MAX_DDS_OFFSET, USER_MAX_DDS_OFFSET));

  wxFloatingPointValidator<float> valFreq(3, &m_freq, wxNUM_VAL_DEFAULT);
  valFreq.SetRange(USER_MIN_DDS_FREQ, USER_MAX_DDS_FREQ);
  m_textCtrlFreq->SetValidator(valFreq);

  wxIntegerValidator<unsigned short> valAmp(&m_amp);
  valAmp.SetRange(0, USER_MAX_DDS_AMP);
  m_textCtrlAmp->SetValidator(valAmp);

  wxIntegerValidator<short> valOffset(&m_offset);
  valOffset.SetRange(-USER_MAX_DDS_OFFSET, USER_MAX_DDS_OFFSET);
  m_textCtrlOffset->SetValidator(valOffset);
}

DDSParamDialog::~DDSParamDialog()
{
}

void DDSParamDialog::OnInitDialog(wxInitDialogEvent &event)
{
  m_hard.GetDDSParam(&m_freq, &m_amp, &m_offset);
  TransferDataToWindow();
}

void DDSParamDialog::OKButton_OnClick(wxCommandEvent &event)
{
  if (Validate() && TransferDataFromWindow())
  {
    if (!m_hard.SetDDSParam(m_freq, m_amp, m_offset))
    {
      wxMessageBox(m_hard.GetLastErrorMessage());
    }

    if (IsModal())
    {
      EndModal(wxID_OK);
    }
    else
    {
      SetReturnCode(wxID_OK);
      Show(false);
    }
  }
  else
  {
    wxBell();
  }
}

//--------------------------------------------------------------------------------
