#include "stdafx.h"
#include "InputBox.h"

//--------------------------------------------------------------------------------
InputBoxDialog::InputBoxDialog(wxWindow *parent, wxString const &title, wxString const &prompt)
  : InputBoxDialogDesign(parent, wxID_ANY, title)
{
  m_staticTextPrompt->SetLabelText(prompt);
}

InputBoxDialog::~InputBoxDialog()
{
}

void InputBoxDialog::SetTextValidator(wxValidator const &validator)
{
  m_textCtrl->SetValidator(validator);
}

void InputBoxDialog::OnInitDialog(wxInitDialogEvent &event)
{
  TransferDataToWindow();
}

void InputBoxDialog::OKButton_OnClick(wxCommandEvent &event)
{
  if (Validate() && TransferDataFromWindow())
  {
    if (IsModal())
    {
      EndModal(wxID_OK);
    }
    else
    {
      SetReturnCode(wxID_OK);
      Show(false);
    }
  }
  else
  {
    wxBell();
  }
}

//--------------------------------------------------------------------------------
int InputBoxInt(int &value, wxString const &prompt, wxString const &title, wxWindow *parent,
                int valueMin, int valueMax, int valueStyle)
{
  InputBoxDialog dlg(parent, title, prompt);

  wxIntegerValidator<int> validator(&value, valueStyle);
  validator.SetRange(valueMin, valueMax);
  dlg.SetTextValidator(validator);

  return dlg.ShowModal();
}

int InputBoxFlt(float &value, wxString const &prompt, wxString const &title, wxWindow *parent,
                float valueMin, float valueMax, int precision, int valueStyle)
{
  InputBoxDialog dlg(parent, title, prompt);

  wxFloatingPointValidator<float> validator(precision, &value, valueStyle);
  validator.SetRange(valueMin, valueMax);
  dlg.SetTextValidator(validator);

  return dlg.ShowModal();
}

int InputBoxDbl(double &value, wxString const &prompt, wxString const &title, wxWindow *parent,
                double valueMin, double valueMax, int precision, int valueStyle)
{
  InputBoxDialog dlg(parent, title, prompt);

  wxFloatingPointValidator<double> validator(precision, &value, valueStyle);
  validator.SetRange(valueMin, valueMax);
  dlg.SetTextValidator(validator);

  return dlg.ShowModal();
}

//--------------------------------------------------------------------------------
