#pragma once

#include "OscilloscopeHard.h"
#include "LockIn.h"
#include "SweepTable.h"
#include "SweepControl.h"

//--------------------------------------------------------------------------------
/**
 * Main Frame.
 */
class MainFrame : public MainFrameDesign
{
public:
  MainFrame();
  virtual ~MainFrame();

protected:
  void OnTimer(wxTimerEvent &event);

  virtual void PanelWaveform_OnPaint(wxPaintEvent &event);
  virtual void PanelWaveform_OnSize(wxSizeEvent &event);
	virtual void PanelFreqResponse_OnPaint(wxPaintEvent &event);
  virtual void PanelFreqResponse_OnSize(wxSizeEvent &event);

  // Grid events.
  virtual void GridSweep_OnGridLabelLeftDClick(wxGridEvent &event);
  virtual void GridSweep_OnGridLabelRightClick(wxGridEvent &event);

  // Menu events.
  virtual void MenuItemApplyCurrentSweepParam( wxCommandEvent &event);
  virtual void MenuItemLoad_OnMenuSelection(wxCommandEvent &event);
  virtual void MenuItemSave_OnMenuSelection(wxCommandEvent &event);
  virtual void MenuItemSaveWaveform_OnMenuSelection(wxCommandEvent &event);
  virtual void MenuItemExit_OnMenuSelection(wxCommandEvent &event);
  virtual void MenuItemSetOscParam_OnMenuSelection(wxCommandEvent &event);
  virtual void MenuItemSetDDSParam_OnMenuSelection(wxCommandEvent &event);
  virtual void MenuItemEnableDDS_OnMenuSelection(wxCommandEvent &event);
  virtual void MenuItemEnableDDS_OnUpdateUI(wxUpdateUIEvent &event);
  virtual void MenuItemStart_OnMenuSelection(wxCommandEvent &event);
  virtual void MenuItemAbort_OnMenuSelection(wxCommandEvent &event);
  virtual void MenuItemSetSweepPoints_OnMenuSelection(wxCommandEvent &event);
  virtual void MenuItemSetupAverage_OnMenuSelection(wxCommandEvent &event);
  virtual void MenuItemSetupFreq_OnMenuSelection(wxCommandEvent &event);
  virtual void MenuItemSetupAmp_OnMenuSelection(wxCommandEvent &event);
  virtual void MenuItemSetupOffset_OnMenuSelection(wxCommandEvent &event);
  virtual void MenuItemSetupVoltDiv_OnMenuSelection(wxCommandEvent &event);
  virtual void MenuItemOptimizeVoltDiv_OnMenuSelection(wxCommandEvent &event);
  virtual void MenuItemShowCh1_2_OnMenuSelection(wxCommandEvent &event);
  virtual void MenuItemShowCh1_2_OnUpdateUI(wxUpdateUIEvent &event);
  virtual void MenuItemShowCh1_3_OnMenuSelection(wxCommandEvent &event);
  virtual void MenuItemShowCh1_3_OnUpdateUI(wxUpdateUIEvent &event);
  virtual void MenuItemShowCh1_4_OnMenuSelection(wxCommandEvent &event);
  virtual void MenuItemShowCh1_4_OnUpdateUI(wxUpdateUIEvent &event);
  virtual void MenuItemLogScale_OnMenuSelection(wxCommandEvent &event);
  virtual void MenuItemLogScale_OnUpdateUI(wxUpdateUIEvent &event);
  virtual void MenuItemAbout_OnMenuSelection(wxCommandEvent &event);

private:
  void UpdateStatusBar();
  bool CheckHardGood();
  void BeforeUserAction();
  void AfterUserAction();

  wxTimer m_timer;
  OscilloscopeHard m_hard;
  LockIn m_lockIn;
  SweepTable *m_table;
  SweepControl *m_ctrl;

  bool m_dataRequested;       // Flag for requesting the next data.
  bool m_hardGood;            // Flag for good status of the oscilloscape.

  // Freq. response view settings.
  bool m_freqResChEnabled[MAX_CH_NUM - 1];
  bool m_freqResLogScale;
};

//--------------------------------------------------------------------------------
