#include "stdafx.h"
#include "OscilloscopeHard.h"

//-------------------------------------------------------------------------------
struct TimeDivInfo
{
  float fTimeBase;
  float fSampleRate;
  TCHAR const *szCaption;
};

static const TimeDivInfo g_stTimeDivInfo[MAX_TIMEDIV_NUM] =
{
  { 0.000000002f, 250000000.00f, _T("2ns") },   // 2ns,   250MHz,  index = 0 (4CH used)
  { 0.000000005f, 250000000.00f, _T("5ns") },   // 5ns,   250MHz,  index = 1 (4CH used)
  { 0.00000001f,  250000000.00f, _T("10ns") },  // 10ns,  250MHz,  index = 2 (4CH used)
  { 0.00000002f,  250000000.00f, _T("20ns") },  // 20ns,  250MHz,  index = 3 (4CH used)
  { 0.00000005f,  250000000.00f, _T("50ns") },  // 50ns,  250MHz,  index = 4 (4CH used)
  { 0.0000001f,   250000000.00f, _T("100ns") }, // 100ns, 250MHz,  index = 5 (4CH used)
  { 0.0000002f,   250000000.00f, _T("200ns") }, // 200ns, 250MHz,  index = 6 (4CH used)
  { 0.0000005f,   250000000.00f, _T("500ns") }, // 500ns, 250MHz,  index = 7 (4CH used)
  { 0.000001f,    250000000.00f, _T("1us") },   // 1us,   250MHz,  index = 8
  { 0.000002f,    125000000.00f, _T("2us") },   // 2us,   125MHz,  index = 9
  { 0.000005f,     50000000.00f, _T("5us") },   // 5us,   50MHz,   index = 10
  { 0.00001f,      25000000.00f, _T("10us") },  // 10us,  25MHz,   index = 11
  { 0.00002f,      12500000.00f, _T("20us") },  // 20us,  12.5MHz, index = 12
  { 0.00005f,       5000000.00f, _T("50us") },  // 50us,  5MHz,    index = 13
  { 0.0001f,        2500000.00f, _T("100us") }, // 100us, 2.5MHz,  index = 14
  { 0.0002f,        1250000.00f, _T("200us") }, // 200us, 1.25MHz, index = 15
  { 0.0005f,         500000.00f, _T("500us") }, // 500us, 500kHz,  index = 16
  { 0.001f,          250000.00f, _T("1ms") },   // 1ms,   250kHz,  index = 17
  { 0.002f,          125000.00f, _T("2ms") },   // 2ms,   125kHz,  index = 18
  { 0.005f,           50000.00f, _T("5ms") },   // 5ms,   50kHz,   index = 19
  { 0.01f,            25000.00f, _T("10ms") },  // 10ms,  25kHz,   index = 20
  { 0.02f,            12500.00f, _T("20ms") },  // 20ms,  12.5kHz, index = 21
  { 0.05f,             5000.00f, _T("50ms") },  // 50ms,  5kHz,    index = 22
  { 0.1f,              2500.00f, _T("100ms") }, // 100ms, 2.5kHz,  index = 23
  { 0.2f,              1250.00f, _T("200ms") }, // 200ms, 1.25kHz, index = 24
  { 0.5f,               500.00f, _T("500ms") }, // 500ms, 500Hz,   index = 25
  { 1.0f,               250.00f, _T("1s") },    // 1s,    250Hz,   index = 26
  { 2.0f,               125.00f, _T("2s") },    // 2s,    125Hz,   index = 27
  { 5.0f,                50.00f, _T("5s") },    // 5s,    50Hz,    index = 28
  { 10.0f,               25.00f, _T("10s") },   // 10s,   25Hz,    index = 29
  { 20.0f,               12.50f, _T("20s") },   // 20s,   12.5Hz,  index = 30
  { 50.0f,                5.00f, _T("50s") },   // 50s,   5Hz,     index = 31
  { 100.0f,               2.50f, _T("100s") },  // 100s,  2.5Hz,   index = 32
  { 200.0f,               1.25f, _T("200s") },  // 200s,  1.25Hz,  index = 33
  { 500.0f,               0.50f, _T("500s") },  // 500s,  0.5Hz,   index = 34
  { 1000.0f,              0.25f, _T("1000s") }  // 1000s, 0.25kHz, index = 35
};

struct VoltDivInfo
{
  float fVoltBase;
  TCHAR const *szCaption;
};

static const VoltDivInfo g_stVoltDivInfo[MAX_VOLTDIV_NUM] =
{
  {  0.002f, _T("2mV") },     // 2mV
  {  0.005f, _T("5mV") },     // 5mV
  {  0.010f, _T("10mV") },    // 10mV
  {  0.020f, _T("20mV") },    // 20mV
  {  0.050f, _T("50mV") },    // 50mV
  {  0.100f, _T("100mV") },   // 100mV
  {  0.200f, _T("200mV") },   // 200mV
  {  0.500f, _T("500mV") },   // 500mV
  {  1.000f, _T("1V") },      // 1V
  {  2.000f, _T("2V") },      // 2V
  {  5.000f, _T("5V") },      // 5V
  { 10.000f, _T("10V") }      // 10V
};

//--------------------------------------------------------------------------------
OscilloscopeHard::OscilloscopeHard()
{
  m_nDeviceIndex = 0;

  for (int i = 0; i < MAX_CH_NUM; i++)
	{
		m_pDispData[i] = new short[BUF_4K_LEN];
    m_pVoltData[i] = new float[BUF_4K_LEN];
	}

  // Trigger settings.
  m_nTriggerMode = EDGE;
  m_nTriggerSweep = AUTO;
  m_nTriggerSlope = RISE;
  m_nTriggerSource = CH1;
  m_nTriggerLevel = 0;      // 0mV

  for (int i = 0; i < MAX_CH_NUM; i++)
  {
    m_nCHVoltDIV[i] = 8;    // Voltage base = 1V, range = 8V
    m_nCHCoupling[i] = AC;  // AC coupling
  }

  m_nTimeDIV = 12;          // Time base = 20us, Sampling rate = 12.5MSa
  m_nYTFormat = YT_NORMAL;
  
	m_nLeverPos[CH1] = 192;
	m_nLeverPos[CH2] = 160;
	m_nLeverPos[CH3] = 96;
	m_nLeverPos[CH4] = 64; 

	m_clrRGB[CH1] = RGB(255,255,0);
	m_clrRGB[CH2] = RGB(0,255,255);
	m_clrRGB[CH3] = RGB(255,0,255);
	m_clrRGB[CH4] = RGB(0,255,0);
	
	m_nReadOK = 0;
  m_bInit = FALSE;

  // DDS settings.
  m_fDDSFrequency = 10000;
  m_nDDSAmp = 100;
  m_nDDSOffset = 0;
  m_bDDSEnabled = FALSE;

  ClearError();
}

OscilloscopeHard::~OscilloscopeHard()
{
	for(int i = 0; i < MAX_CH_NUM; i++)
	{
		delete [] m_pDispData[i];
    delete [] m_pVoltData[i];
	}
}

BOOL OscilloscopeHard::Init()
{
  wxASSERT(!m_bInit);
  ClearError();

  SHORT devInfos[32];
  WORD nConnectedDevNum = ::dsoHTSearchDevice(devInfos);
  if (0 == nConnectedDevNum || -1 == devInfos[0])
  {
    SetError(_("Oscilloscope device is not connected!"));
    return FALSE;
  }

	m_nDeviceIndex = 0;
  if (!dsoInitHard(m_nDeviceIndex))
  {
    SetError(_("Failed to initialize device!"));
    return FALSE;
  }

  // Setup to use 4 channels.
  if (!dsoHTADCCHModGain(m_nDeviceIndex,4))
  {
    SetError(_("Failed to setup channels!"));
    return FALSE;
  }

  m_bInit = TRUE;

  // Apply default condition.
  if (!ApplyCondition()) return FALSE;

  // Apply default DDS parameter.
  if (!SetDDSParam(10000, 100, 0)) return FALSE;
  if (!EnableDDS(FALSE)) return FALSE;
  
  return TRUE;
}

void OscilloscopeHard::SetTimeDiv(USHORT nTimeDiv)
{
  wxASSERT(m_bInit);
  wxASSERT(nTimeDiv <= MAX_TIMEDIV_NUM - 1);
  m_nTimeDIV = nTimeDiv;
}

void OscilloscopeHard::SetTriggerParam(WORD nSource, USHORT nSlope, SHORT nLevel)
{
  wxASSERT(m_bInit);
  wxASSERT(nSource >= CH1 && nSource <= CH4);
  wxASSERT(nSlope == RISE || nSlope == FALL);
  m_nTriggerSource = nSource;
  m_nTriggerSlope = nSlope;
  m_nTriggerLevel = nLevel;
}

void OscilloscopeHard::GetTriggerParam(WORD *pnSource, USHORT *pnSlope, SHORT *pnLevel) const
{
  if (*pnSource != NULL) *pnSource = m_nTriggerSource;
  if (*pnSlope != NULL) *pnSlope = m_nTriggerSlope;
  if (*pnLevel != NULL) *pnLevel = m_nTriggerLevel;
}

void OscilloscopeHard::SetVoltDiv(USHORT nCH, WORD nCHVoltDIV)
{
  wxASSERT(m_bInit);
  wxASSERT(nCH >= CH1 && nCH <= CH4);
  wxASSERT(nCHVoltDIV <= MAX_VOLTDIV_NUM - 1);
  m_nCHVoltDIV[nCH] = nCHVoltDIV;
}

WORD OscilloscopeHard::GetVoltDiv(USHORT nCH) const
{
  wxASSERT(nCH >= CH1 && nCH <= CH4);
  return m_nCHVoltDIV[nCH];
}

void OscilloscopeHard::SetCoupling(USHORT nCH, WORD nCHCoupling)
{
  wxASSERT(m_bInit);
  wxASSERT(nCH >= CH1 && nCH <= CH4);
  wxASSERT(nCHCoupling == DC || nCHCoupling == AC);
  m_nCHCoupling[nCH] = nCHCoupling;
}

WORD OscilloscopeHard::GetCoupling(USHORT nCH) const
{
  wxASSERT(nCH >= CH1 && nCH <= CH4);
  return m_nCHCoupling[nCH];
}

BOOL OscilloscopeHard::ApplyCondition()
{
  wxASSERT(m_bInit);
  ClearError();

  CONTROLDATA stControl;
  RELAYCONTROL stRelayControl;
  MakeControlData(stControl, stRelayControl);

  // Set sampling rate.
	if (!dsoHTSetSampleRate(m_nDeviceIndex, m_nYTFormat, &stRelayControl, &stControl))
  {
    SetError(_("Failed to set sampling rate!"));
    return FALSE;
  }
  
  // Set channel switch and voltage range.
  if (!dsoHTSetCHAndTrigger(m_nDeviceIndex, &stRelayControl, stControl.nTimeDIV))
  {
    SetError(_("Failed to set voltage ranges!"));
    return FALSE;
  }
  
  // Set trigger source.
	if (!dsoHTSetRamAndTrigerControl(m_nDeviceIndex, stControl.nTimeDIV, stControl.nCHSet, stControl.nTriggerSource, 0))
  {
    SetError(_("Failed to set trigger source!"));
    return FALSE;
  }

  // Set channel position.
	for(int i = 0; i < MAX_CH_NUM; i++)
	{
		if (!dsoHTSetCHPos(m_nDeviceIndex, stRelayControl.nCHVoltDIV[i], m_nLeverPos[i], i, 4))
    {
      SetError(_("Failed to set channel position!"));
      return FALSE;
    }
	}
  
  // Set trigger level.
	if (!dsoHTSetVTriggerLevel(m_nDeviceIndex, stControl.nVTriggerPos, 4))
  {
    SetError(_("Failed to set trigger level"));
    return FALSE;
  }

  // Set trigger mode.
  if (!dsoHTSetTrigerMode(m_nDeviceIndex, m_nTriggerMode, stControl.nTriggerSlope, AC))
  {
    SetError(_("Failed to set trigger mode!"));
    return FALSE;
  }

  return TRUE;
}

BOOL OscilloscopeHard::StartCollect()
{
  wxASSERT(m_bInit);
  ClearError();

  WORD nStartControl = 0;
  nStartControl |= ((m_nTriggerSweep == AUTO) ? 0x01 : 0);   //add by zhang
  nStartControl |= ((m_nYTFormat== YT_ROLL)   ? 0x02 : 0);   //add by zhang
  //nStartControl |= m_bCollect ? 0 : 0x04;                    //add by zhang

  if (!dsoHTStartCollectData(m_nDeviceIndex, nStartControl))
  {
    SetError(_("Failed to start collecting data!"));
    return FALSE;
  }

  return TRUE;
}

BOOL OscilloscopeHard::CheckCollected()
{
  wxASSERT(m_bInit);

	WORD nState = dsoHTGetState(m_nDeviceIndex);
	return (nState & 0x02) != 0;
}

BOOL OscilloscopeHard::ReadData()
{
  wxASSERT(m_bInit);
  ClearError();

  CONTROLDATA stControl;
  RELAYCONTROL stRelayControl;
  MakeControlData(stControl, stRelayControl);

	USHORT *pReadData[MAX_CH_NUM];
	for (int i = 0; i < MAX_CH_NUM; i++)
	{
		pReadData[i] = new USHORT[stControl.nReadDataLen];
		memset(pReadData[i], 0, stControl.nReadDataLen * sizeof(USHORT));
	}
	m_nReadOK = dsoHTGetData(m_nDeviceIndex, pReadData[CH1], pReadData[CH2], pReadData[CH3], pReadData[CH4], &stControl);

  // (Actual voltage value at j-th point per channel i) = (pReadData[i][j] - m_nLeverPos[i]) * 8 * (Voltage Value) / 255
	if (m_nReadOK)
	{
		for(int i = 0; i < MAX_CH_NUM; i++)
		{
			SourceToDisplay(pReadData[i], stControl.nReadDataLen, i); // For the convenience of display
      SourceToVoltage(pReadData[i], stControl.nReadDataLen, i); // Convert to voltage data.
		}
	}
  else
  {
    SetError(_("Failed to read collected data!"));
  }

	for(int i = 0; i < MAX_CH_NUM; i++)
	{
		delete pReadData[i];
	}

  return m_nReadOK;
}

ULONG OscilloscopeHard::GetDataSize() const
{
  return BUF_4K_LEN;
}

SHORT const *OscilloscopeHard::GetDisplayData(USHORT nCH) const
{
  wxASSERT(nCH >= CH1 && nCH <= CH4);
  return m_pDispData[nCH];
}

float const *OscilloscopeHard::GetVoltageData(USHORT nCH) const
{
  wxASSERT(nCH >= CH1 && nCH <= CH4);
  return m_pVoltData[nCH];
}

void OscilloscopeHard::Draw(HDC hDC, RECT const &Rect)
{
  wxASSERT(m_bInit);
  ClearError();

  DrawGrid(hDC, Rect);
  
  if(m_bInit > 0)
  {
    DrawWave(hDC, Rect);
  }
}

void OscilloscopeHard::DrawText(HDC hDC, USHORT nCH, wxString text)
{
  wxASSERT(nCH >= CH1 && nCH <= CH4);
  wxCStrData cstr = text.c_str();
  ::SetTextColor(hDC, m_clrRGB[nCH]);
  ::TextOut(hDC, 10, 10 + nCH * 20, cstr, strlen(cstr)); 
}

BOOL OscilloscopeHard::SaveWaveform(wxString const &fileName) const
{
  wxASSERT(m_bInit);
  ClearError();

  FILE *file = ::fopen(fileName.c_str(), "wt");
  if (NULL == file)
  {
    SetError(_("Failed to open file!"));
    return FALSE;
  }

  ::fprintf(file, "Time[s],CH1[V],CH2[V],CH3[V],CH4[V]\n");

  int size = GetDataSize();

  double sr = OscilloscopeHard::SampleRate(m_nTimeDIV);
  double T = 1.0 / sr;

  for (int i = 0; i < size; ++i)
  {
    double time = T * (i - size / 2);
    ::fprintf(file, "%lg,%g,%g,%g,%g\n",
              time, m_pVoltData[CH1][i], m_pVoltData[CH2][i], m_pVoltData[CH3][i], m_pVoltData[CH4][i]);
  }

  ::fclose(file);

  return TRUE;
}

BOOL OscilloscopeHard::SetDDSParam(float fFrequency, USHORT nAmp, SHORT nOffset)
{
  wxASSERT(m_bInit);
  ClearError();

  if (!ddsSetCmd(m_nDeviceIndex, 0))  // Set continual wave.
  {
    SetError(_("Failed to set DDS wave type!"));
    return FALSE;
  }

  ddsSDKSetFre(m_nDeviceIndex, fFrequency);
  ddsSDKSetAmp(m_nDeviceIndex, nAmp);
  ddsSDKSetOffset(m_nDeviceIndex, nOffset);
  ddsSDKSetWaveType(m_nDeviceIndex, WAVE_SINE);

  m_fDDSFrequency = fFrequency;
  m_nDDSAmp = nAmp;
  m_nDDSOffset = nOffset;

  return TRUE;
}

void OscilloscopeHard::GetDDSParam(float *pfFrequency, USHORT *pnAmp, SHORT *pnOffset) const
{
  if (pfFrequency != NULL) *pfFrequency = m_fDDSFrequency;
  if (pnAmp != NULL) *pnAmp = m_nDDSAmp;
  if (pnOffset != NULL) *pnOffset = m_nDDSOffset;
}

BOOL OscilloscopeHard::EnableDDS(BOOL bEnabled)
{
  wxASSERT(m_bInit);
  ClearError();

  if (!ddsSetOnOff(m_nDeviceIndex, bEnabled ? 1 : 0))
  {
    SetError(_("Failed to set ON/OFF of DDS!"));
    return FALSE;
  }

  m_bDDSEnabled = bEnabled;
  return TRUE;
}

void OscilloscopeHard::MakeControlData(CONTROLDATA &stControl, RELAYCONTROL &stRelayControl)
{
  float fTriggerVoltBase = g_stVoltDivInfo[m_nCHVoltDIV[m_nTriggerSource]].fVoltBase;
	stControl.nCHSet = 0x0F;                                // All channels are used.
	stControl.nTimeDIV = m_nTimeDIV;                        // Samplingrate.
	stControl.nTriggerSource = m_nTriggerSource;            // Trigger source.
	stControl.nHTriggerPos = 50;                            // Set horizontal trigger position (0-100).
	stControl.nVTriggerPos = (WORD)(m_nLeverPos[m_nTriggerSource] + 255.0f * ((float)m_nTriggerLevel / 1000.0f) / (8.0f * fTriggerVoltBase));
	stControl.nTriggerSlope = m_nTriggerSlope;              // Trigger slope.
	stControl.nBufferLen = BUF_4K_LEN;                      // Buffer length.
	stControl.nReadDataLen = BUF_4K_LEN;                    // Read data length.
	stControl.nAlreadyReadLen = 0;                          // Only valid in the case of scan scrolling, used to record the length that has been read.
	stControl.nALT = 0;                                     // Factory Setup

	for (int i = 0; i < MAX_CH_NUM; i++)
	{
		stRelayControl.bCHEnable[i] = 1;
		stRelayControl.nCHVoltDIV[i] = m_nCHVoltDIV[i];
		stRelayControl.nCHCoupling[i] = m_nCHCoupling[i];
		stRelayControl.bCHBWLimit[i] = 0;
	}	
	stRelayControl.nTrigSource = m_nTriggerSource;
	stRelayControl.bTrigFilt = 0;
	stRelayControl.nALT = 0;
}

void OscilloscopeHard::SourceToDisplay(USHORT* pData, ULONG nDataLen, USHORT nCH)
{
	for (ULONG i = 0; i < nDataLen; i++)
	{
		*(m_pDispData[nCH] + i) = *(pData + i) - (MAX_DATA - m_nLeverPos[nCH]);
	}
}

void OscilloscopeHard::SourceToVoltage(USHORT* pData, ULONG nDataLen, USHORT nCH)
{
  float fVoltBase = g_stVoltDivInfo[m_nCHVoltDIV[nCH]].fVoltBase;
  float fScale = (8.0f * fVoltBase) / 255.0f;
	for (ULONG i = 0; i < nDataLen; i++)
	{
		*(m_pVoltData[nCH] + i) = ((float)(*(pData + i)) - (float)m_nLeverPos[nCH]) * fScale;
	}
}

void OscilloscopeHard::DrawWave(HDC hDC, RECT const &Rect)
{
  for(int i = 0; i < MAX_CH_NUM; i++)
  {
    DrawWaveInYT(hDC, Rect, i);
  }
}

void OscilloscopeHard::DrawWaveInYT(HDC hDC, RECT const &Rect, USHORT nCH)
{
  SHORT * pData = (SHORT *)GetDisplayData(nCH);     // Source data.
  ULONG nSrcDataLen = GetDataSize();                // The length of source data.
  ULONG nDisDataLen = 2500;                         // The length of requested data.
  USHORT nDisLeverPos = m_nLeverPos[nCH];           // Position of zero.
  ULONG nCenterData = nSrcDataLen / 2;              // Center of data.
  COLORREF clrRGB = m_clrRGB[nCH];                  // Color.
  USHORT nHTriggerPos = 50;                         // Horizontal trigger position (0-100).
  USHORT nYTFormat = 0;
  USHORT nDisType = 0;                              // Display type.
  double dbVertical = 1.0;                          //
  double dbHorizontal = 1.0;
  HTDrawWaveInYT(hDC, Rect, clrRGB, nDisType, pData, nSrcDataLen, nDisDataLen,
                 nCenterData, nDisLeverPos, dbHorizontal, dbVertical, nYTFormat, 0); 
}

void OscilloscopeHard::DrawGrid(HDC hDC, RECT const &Rect)
{
  HTDrawGrid(hDC, Rect.left, Rect.top, Rect.right, Rect.bottom, 10, 8, 200, 1);
}

//--------------------------------------------------------------------------------
wxString OscilloscopeHard::TimeDivToString(USHORT nTimeDiv)
{
  wxASSERT(nTimeDiv < MAX_TIMEDIV_NUM);
  return g_stTimeDivInfo[nTimeDiv].szCaption;
}

USHORT OscilloscopeHard::TimeDivFromString(wxString const &str)
{
  for (USHORT i = 0; i < MAX_TIMEDIV_NUM; ++i)
  {
    if (str == g_stTimeDivInfo[i].szCaption) return i;
  }
  wxASSERT(false);
  return 0;
}

wxString OscilloscopeHard::VoltDivToString(WORD nVoltDiv)
{
  wxASSERT(nVoltDiv < MAX_VOLTDIV_NUM);
  return g_stVoltDivInfo[nVoltDiv].szCaption;
}

WORD OscilloscopeHard::VoltDivFromString(wxString const &str)
{
  for (WORD i = 0; i < MAX_VOLTDIV_NUM; ++i)
  {
    if (str == g_stVoltDivInfo[i].szCaption) return i;
  }
  wxASSERT(false);
  return 0;
}

wxArrayString OscilloscopeHard::GetChannelTexts()
{
  wxArrayString strings;
  strings.push_back(_("CH1"));
  strings.push_back(_("CH2"));
  strings.push_back(_("CH3"));
  strings.push_back(_("CH4"));
  return strings;
}

wxArrayString OscilloscopeHard::GetTimeDivTexts()
{
  wxArrayString strings;
  for (int i = 0; i < MAX_TIMEDIV_NUM; ++i)
  {
    strings.push_back(g_stTimeDivInfo[i].szCaption);
  }
  return strings;
}

wxArrayString OscilloscopeHard::GetVoltDivTexts()
{
  wxArrayString strings;
  for (int i = 0; i < MAX_VOLTDIV_NUM; ++i)
  {
    strings.push_back(g_stVoltDivInfo[i].szCaption);
  }
  return strings;
}

wxArrayString OscilloscopeHard::GetTriggerSlopeTexts()
{
  wxArrayString strings;

  strings.push_back(_("Rise"));   // 0, RISE
  strings.push_back(_("Fall"));   // 1, FALL

  return strings;
}

wxArrayString OscilloscopeHard::GetCouplingTexts()
{
  wxArrayString strings;

  strings.push_back(_("DC"));     // 0, DC
  strings.push_back(_("AC"));     // 1, AC

  return strings;
}

float OscilloscopeHard::SampleRate(USHORT nTimeDIV)
{
  wxASSERT(nTimeDIV < MAX_TIMEDIV_NUM);
  return g_stTimeDivInfo[nTimeDIV].fSampleRate;
}

float OscilloscopeHard::ValueOfTimeDiv(USHORT nTimeDIV)
{
  wxASSERT(nTimeDIV < MAX_TIMEDIV_NUM);
  return g_stTimeDivInfo[nTimeDIV].fTimeBase;
}

float OscilloscopeHard::ValueOfVoltDiv(WORD nVoltDIV)
{
  wxASSERT(nVoltDIV < MAX_VOLTDIV_NUM);
  return g_stVoltDivInfo[nVoltDIV].fVoltBase;
}

//--------------------------------------------------------------------------------
