﻿#include "stdafx.h"
#include "OscilloscopePanel.h"

//--------------------------------------------------------------------------------
OscilloscopePanel::OscilloscopePanel(wxWindow *parent)
  : wxPanel(parent)
{
  m_timer.SetOwner(this, wxID_ANY);

	short nDevInfo[MAX_USB_DEV_NUMBER];	
	m_Hard.m_nDeviceNum = dsoHTSearchDevice(nDevInfo);
	if(m_Hard.m_nDeviceNum > 0)
	{
		m_Hard.Init();
    m_timer.Start(30);
	}
	else
	{
		wxMessageBox(_T("No suitble device was found!"));
	}

  Connect(wxEVT_TIMER, wxTimerEventHandler(OscilloscopePanel::OnTimer));
  Connect(wxEVT_SIZE,  wxSizeEventHandler(OscilloscopePanel::OnSize));
  Connect(wxEVT_PAINT, wxPaintEventHandler(OscilloscopePanel::OnPaint));
}

OscilloscopePanel::~OscilloscopePanel()
{
  Disconnect(wxEVT_TIMER, wxTimerEventHandler(OscilloscopePanel::OnTimer));
  Disconnect(wxEVT_SIZE,  wxSizeEventHandler(OscilloscopePanel::OnSize));
  Disconnect(wxEVT_PAINT, wxPaintEventHandler(OscilloscopePanel::OnPaint));
}

void OscilloscopePanel::CollectData()
{
	short nState = 0;

	if(m_bStartNew)
	{
    WORD nStartControl = 0;
    nStartControl |= ((m_Hard.m_nTriggerSweep == AUTO) ? 0x01 : 0);   //add by zhang
    nStartControl |= ((m_Hard.m_nYTFormat== YT_ROLL)   ? 0x02 : 0);   //add by zhang
    nStartControl |= m_Hard.m_bCollect ? 0 : 0x04;                    //add by zhang
    dsoHTStartCollectData(m_Hard.m_nDeviceIndex, nStartControl);
    //	dsoHTStartTrigger(m_Hard.m_nDeviceIndex);
    //		m_nAutoTriggerCnt = 0;
    m_bStartNew = FALSE;
	}
	nState = dsoHTGetState(m_Hard.m_nDeviceIndex);
	if(nState & 0x02)	
	{
		m_Hard.ReadData();
		m_bStartNew = TRUE;		
	}
  else
  {
		m_bStartNew = FALSE;	
	}
}

void OscilloscopePanel::DrawWave(HDC hDC, RECT const &Rect)
{
	int i = 0;
	//CH1/CH2/CH3/CH4
	for(i=0; i < MAX_CH_NUM; i++)
	{
		DrawWaveInYT(hDC, Rect, i);
	}
}

void OscilloscopePanel::DrawWaveInYT(HDC hDC, RECT const &Rect, USHORT nCH)
{
	short* pData = m_Hard.m_pSrcData[nCH];  // 元データ
	ULONG nDisDataLen = 2500;               // 要求のデータ長
	ULONG nSrcDataLen = BUF_4K_LEN;         // ソースデータの長さ
	USHORT nDisLeverPos = m_Hard.m_nLeverPos[nCH];  // ゼロの表示位置
	ULONG nCenterData = BUF_4K_LEN/2;       //
	COLORREF clrRGB = m_Hard.m_clrRGB[nCH]; // 色
	USHORT nHTriggerPos = m_Hard.m_stControl.nHTriggerPos; // 水平位置
	USHORT nYTFormat = 0;
	USHORT nDisType = 0;                    // 表示タイプ、点または線
	double dbVertical = 1.0;                //
	double dbHorizontal = 1.0;
	//HTDrawWaveInYT(pDC->GetSafeHdc(),Rect,clrRGB,nDisType,pData,nSrcDataLen,nDisDataLen,nCenterData,nDisLeverPos,dbHorizontal,dbVertical,nYTFormat,m_pDoc->m_Hard.m_stControl.nAlreadyReadLen);//DLL import
 	HTDrawWaveInYT(hDC, Rect, clrRGB, nDisType, pData, nSrcDataLen, nDisDataLen, nCenterData, nDisLeverPos,
		dbHorizontal, dbVertical, nYTFormat, m_Hard.m_stControl.nAlreadyReadLen); //DLL import
}

void OscilloscopePanel::DrawGrid(HDC hDC, RECT const &Rect)
{
  HTDrawGrid(hDC, Rect.left, Rect.top, Rect.right, Rect.bottom, 10, 8, 200, 1); //DLL import
}

void OscilloscopePanel::OnSize(wxSizeEvent &event)
{

}

void OscilloscopePanel::OnTimer(wxTimerEvent &event)
{
	CollectData();
	if (m_bStartNew == TRUE)
  {
	  Refresh(false);
  }
}

void OscilloscopePanel::OnPaint(wxPaintEvent &event)
{
  wxPaintDC dc(this);
  
  wxRect rect = GetClientRect();
  if (0 == rect.width || 0 == rect.height)
  {
    return;
  }

  RECT winrect;
  winrect.top = rect.y;
  winrect.left = rect.x;
  winrect.bottom = rect.y + rect.height;
  winrect.right = rect.x + rect.width;

  // Get the handle of the wxWindow
  HWND hwnd = static_cast<HWND>(GetHandle());

  // Now get the native windows DC for this window
  HDC hdc = ::GetDC(hwnd);

  // Create a double buffer for blitting to
  // the screen to prevent screen flicker. Pass
  // the double buffer to cairo and blit it
  // in the paint routine.
  HDC dcbuffer = ::CreateCompatibleDC(hdc);
  HBITMAP hbuffer = ::CreateCompatibleBitmap(hdc, rect.width, rect.height);
  SelectObject(dcbuffer, hbuffer); 

	DrawGrid(dcbuffer, winrect);
	
	if(m_Hard.m_nDeviceNum > 0)
	{
		DrawWave(dcbuffer, winrect);
	}

  // Now blit the object to the screen
  ::BitBlt(hdc, 0, 0, rect.width, rect.height, dcbuffer, 0, 0, SRCCOPY);

  ::DeleteDC(dcbuffer);
  ::DeleteObject(hbuffer);

  // Because we called ::GetDC make sure we release the handle
  // back to the system or we'll have a memory leak.
  ::ReleaseDC(hwnd, hdc);
}

//--------------------------------------------------------------------------------
