#include "stdafx.h"
#include "OscilloscopeParamDialog.h"

//--------------------------------------------------------------------------------
OscilloscopeParamDialog::OscilloscopeParamDialog(wxWindow *parent, OscilloscopeHard &hard)
  : OscilloscopeParamDialogDesign(parent),
    m_hard(hard)
{
  wxArrayString channelTexts = OscilloscopeHard::GetChannelTexts();
  wxArrayString timeDivTexts = OscilloscopeHard::GetTimeDivTexts();
  wxArrayString voltDivTexts = OscilloscopeHard::GetVoltDivTexts();
  wxArrayString trgSlopeTexts = OscilloscopeHard::GetTriggerSlopeTexts();
  wxArrayString couplingTexts = OscilloscopeHard::GetCouplingTexts();

  m_choiceTimeDiv->Append(timeDivTexts);
  m_choiceTrgSrc->Append(channelTexts);
  m_choiceTrgSlope->Append(trgSlopeTexts);

  m_choiceVoltDivCH1->Append(voltDivTexts);
  m_choiceCouplingCH1->Append(couplingTexts);
  m_choiceVoltDivCH2->Append(voltDivTexts);
  m_choiceCouplingCH2->Append(couplingTexts);
  m_choiceVoltDivCH3->Append(voltDivTexts);
  m_choiceCouplingCH3->Append(couplingTexts);
  m_choiceVoltDivCH4->Append(voltDivTexts);
  m_choiceCouplingCH4->Append(couplingTexts);

  wxIntegerValidator<SHORT> valTrgLevel(&m_trgLevel);
  m_textCtrlTrgLevel->SetValidator(valTrgLevel);
}

OscilloscopeParamDialog::~OscilloscopeParamDialog()
{
}

void OscilloscopeParamDialog::OnInitDialog(wxInitDialogEvent &event)
{
  m_choiceTimeDiv->SetSelection(m_hard.GetTimeDiv());

  WORD trgSource;
  USHORT trgSlope;
  m_hard.GetTriggerParam(&trgSource, &trgSlope, &m_trgLevel);
  m_choiceTrgSrc->SetSelection(trgSource);
  m_choiceTrgSlope->SetSelection(trgSlope);

  m_choiceVoltDivCH1->SetSelection(m_hard.GetVoltDiv(CH1));
  m_choiceCouplingCH1->SetSelection(m_hard.GetCoupling(CH1));
  m_choiceVoltDivCH2->SetSelection(m_hard.GetVoltDiv(CH2));
  m_choiceCouplingCH2->SetSelection(m_hard.GetCoupling(CH2));
  m_choiceVoltDivCH3->SetSelection(m_hard.GetVoltDiv(CH3));
  m_choiceCouplingCH3->SetSelection(m_hard.GetCoupling(CH3));
  m_choiceVoltDivCH4->SetSelection(m_hard.GetVoltDiv(CH4));
  m_choiceCouplingCH4->SetSelection(m_hard.GetCoupling(CH4));

  TransferDataToWindow();
}

void OscilloscopeParamDialog::OKButton_OnClick(wxCommandEvent &event)
{
  if (Validate() && TransferDataFromWindow())
  {
    m_hard.SetTimeDiv(m_choiceTimeDiv->GetSelection());

    WORD trgSource = m_choiceTrgSrc->GetSelection();
    USHORT trgSlope = m_choiceTrgSlope->GetSelection();
    m_hard.SetTriggerParam(trgSource, trgSlope, m_trgLevel);

    m_hard.SetVoltDiv(CH1, m_choiceVoltDivCH1->GetSelection());
    m_hard.SetCoupling(CH1, m_choiceCouplingCH1->GetSelection());
    m_hard.SetVoltDiv(CH2, m_choiceVoltDivCH2->GetSelection());
    m_hard.SetCoupling(CH2, m_choiceCouplingCH2->GetSelection());
    m_hard.SetVoltDiv(CH3, m_choiceVoltDivCH3->GetSelection());
    m_hard.SetCoupling(CH3, m_choiceCouplingCH3->GetSelection());
    m_hard.SetVoltDiv(CH4, m_choiceVoltDivCH4->GetSelection());
    m_hard.SetCoupling(CH4, m_choiceCouplingCH4->GetSelection());

    if (!m_hard.ApplyCondition())
    {
      wxMessageBox(m_hard.GetLastErrorMessage());
    }

    if (IsModal())
    {
      EndModal(wxID_OK);
    }
    else
    {
      SetReturnCode(wxID_OK);
      Show(false);
    }
  }
  else
  {
    wxBell();
  }
}

//--------------------------------------------------------------------------------
