#pragma once
#include "OscilloscopeHard.h"
#include "LockIn.h"
#include "SweepTable.h"

//------------------------------------------------------------------------
/**
 * State machine for sweep control. 
 */
class SweepControl
{
public:
  enum /* NotifyInfo */
  {
    NOTIFY_NONE             = 0x0,
    NOTIFY_ERROR            = 0x1,
    NOTIFY_TABLE_UPDATED    = 0x2,
    NOTIFY_SWEEP_COMPLETED  = 0x4
  };

  SweepControl(OscilloscopeHard &hard, LockIn &lockIn, SweepTable &table);

  /**
   * Apply DDS and Oscilloscope condition.
   */
  bool ApplySweepCondition(int row);

  /**
   * Start Sweep.
   */
  void StartSweep();

  /**
   * Abort Sweep.
   */
  void AbortSweep();

  /**
   * This method should be called after the oscilloscope read data and lock-in is processed.
   */
  int OnOscilloscopeReadData();

  /**
   * Check whether sweep is running or not.
   */
  bool IsSweeping() const { return m_sweeping; }

  int GetCurrentRow() const { return m_rowCounter; }

  /**
   * Get the message of last error.
   */
  wxString const &GetLastErrorMessage() const { return m_err; }

private:
  SweepControl();
  SweepControl(SweepControl const &);
  SweepControl &operator = (SweepControl const &);

  void ClearError() { m_err.clear(); }
  void SetError(wxString const &err) { m_err = err; }

  OscilloscopeHard &m_hard;
  LockIn &m_lockIn;
  SweepTable &m_table;

  void NewCondition(int row);

  // State.
  bool m_sweeping;
  int m_rowCounter;
  int m_aveCounter;
  int m_waitCounter;

  // Sum of Gain / Phase.
  float m_realSum[MAX_CH_NUM - 1];
  float m_imagSum[MAX_CH_NUM - 1];

  wxString m_err;                   // Error message.
};

//------------------------------------------------------------------------
