#include "stdafx.h"
#include "SweepFrequencyDialog.h"
#include "UserInputRange.h"

//------------------------------------------------------------------------
SweepFrequencyDialog::SweepFrequencyDialog(wxWindow *parent, SweepTable &table)
  : SweepFrequencyDialogDesign(parent),
    m_table(table)
{
  m_staticTextStartFreq->SetLabel(
    wxString::Format(_("Start Frequency (%.1f - %.1f) [Hz]:"), USER_MIN_DDS_FREQ, USER_MAX_DDS_FREQ));
  m_staticTextStopFreq->SetLabel(
    wxString::Format(_("Stop Frequency (%.1f - %.1f) [Hz]:"), USER_MIN_DDS_FREQ, USER_MAX_DDS_FREQ));

  wxFloatingPointValidator<float> valStartFreq(3, &m_startFreq, wxNUM_VAL_DEFAULT);
  m_textCtrlStartFreq->SetValidator(valStartFreq);

  wxFloatingPointValidator<float> valStopFreq(3, &m_stopFreq, wxNUM_VAL_DEFAULT);
  m_textCtrlStopFreq->SetValidator(valStopFreq);
}

SweepFrequencyDialog::~SweepFrequencyDialog()
{
}

void SweepFrequencyDialog::OnInitDialog(wxInitDialogEvent &event)
{
  m_startFreq = m_table[0].ddsFreq;
  m_stopFreq = m_table[m_table.GetSize() - 1].ddsFreq;
  m_checkBoxLogScale->SetValue(true);
  m_checkBoxOptimize->SetValue(true);
  TransferDataToWindow();
}

void SweepFrequencyDialog::OKButton_OnClick(wxCommandEvent &event)
{
  if (Validate() && TransferDataFromWindow())
  {
    if (m_startFreq <= m_stopFreq)
    {
      bool logScale = m_checkBoxLogScale->IsChecked();
      bool optimize = m_checkBoxOptimize->IsChecked();

      m_table.FillFrequency(m_startFreq, m_stopFreq, logScale, optimize);

      if (IsModal())
      {
        EndModal(wxID_OK);
      }
      else
      {
        SetReturnCode(wxID_OK);
        Show(false);
      }
    }
    else
    {
      wxBell();
    }
  }
  else
  {
    wxBell();
  }
}

//------------------------------------------------------------------------
